// Definitions for building in Qt source, ref. src/jconfig.h.in

#define JPEG_LIB_VERSION 80

#define LIBJPEG_TURBO_VERSION 3.1.3

#define LIBJPEG_TURBO_VERSION_NUMBER 3001003

#define C_ARITH_CODING_SUPPORTED 1

#define D_ARITH_CODING_SUPPORTED 1

#define MEM_SRCDST_SUPPORTED 1

#ifndef BITS_IN_JSAMPLE
#define BITS_IN_JSAMPLE  8
#endif

#define NO_PUTENV

